_location_data = [
    {
        "name": "Sudurpaschim Province",
        "name_nepali": "सुदूरपश्चिम प्रदेश",
        "districts": [
            {
                "name": "Bajura",
                "name_nepali": "बाजुरा",
                "municipalities": [
                    {
                        "name": "Himali Rural Municipality",
                        "name_nepali": "हिमाली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gaumul Rural Municipality",
                        "name_nepali": "गौमुल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Badimalika Municipality",
                        "name_nepali": "बडीमालिका नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhededaha Rural Municipality",
                        "name_nepali": "छेडेदह गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Budhiganga Municipality",
                        "name_nepali": "बुढीगंगा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tribeni Municipality",
                        "name_nepali": "त्रिवेणी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Jagannath Rural Municipality",
                        "name_nepali": "जगन्नाथगाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Budhinanda Municipality",
                        "name_nepali": "बुढीनन्दा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Swami Kartik Rural Municipality",
                        "name_nepali": "स्वामीकार्तिक खापर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Bajhang",
                "name_nepali": "बझाङ",
                "municipalities": [
                    {
                        "name": "Kanda Rural Municipality",
                        "name_nepali": "काँडा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bungal Municipality",
                        "name_nepali": "बुङ्गल नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Talkot Rural Municipality",
                        "name_nepali": "तलकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Masta Rural Municipality",
                        "name_nepali": "मष्टा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jayaprithbi Municipality",
                        "name_nepali": "जयपृथ्वी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhabis Pathibhara Rural Municipality",
                        "name_nepali": "छबिसपाथिभेरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Durgathali Rural Municipality",
                        "name_nepali": "दुर्गाथली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bitthadchir Rural Municipality",
                        "name_nepali": "बित्थडचिर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thalara Rural Municipality",
                        "name_nepali": "थलारा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khaptad Chhanna Rural Municipality",
                        "name_nepali": "खप्तडछान्ना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Surma Rural Municipality",
                        "name_nepali": "सूर्मा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kedarsyun Rural Municipality",
                        "name_nepali": "केदारस्यु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Baitadi",
                "name_nepali": "बैतडी",
                "municipalities": [
                    {
                        "name": "Dilasaini Rural Municipality",
                        "name_nepali": "डिलासैनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dogada Kedar Rural Municipality",
                        "name_nepali": "दोगडाकेदार गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Puchaundi Municipality",
                        "name_nepali": "पुर्चौडी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Surnaya Rural Municipality",
                        "name_nepali": "सुर्नया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dasharathchand Municipality",
                        "name_nepali": "दशरथचन्द नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shivanath Rural Municipality",
                        "name_nepali": "शिवनाथ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Melauli Municipality",
                        "name_nepali": "मेलौली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Patan Municipality",
                        "name_nepali": "पाटन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sigas Rural Municipality",
                        "name_nepali": "सिगास गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pancheshwor Rural Municipality",
                        "name_nepali": "पञ्चेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Dadeldhura",
                "name_nepali": "डडेलधुरा",
                "municipalities": [
                    {
                        "name": "Nawadurga Rural Municipality",
                        "name_nepali": "नवदुर्गा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Amargadhi Municipality",
                        "name_nepali": "अमरगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhageshwor Rural Municipality",
                        "name_nepali": "भागेश्वोर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Parashuram Municipality",
                        "name_nepali": "परशुराम नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Aalital Rural Municipality",
                        "name_nepali": "आलिताल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ganyapdhura Rural Municipality",
                        "name_nepali": "गन्यापधुरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ajayameru Rural Municipality",
                        "name_nepali": "अजयमेरु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Doti",
                "name_nepali": "डोटी",
                "municipalities": [
                    {
                        "name": "Purbichouki Rural Municipality",
                        "name_nepali": "पूर्बिचाैकि गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sayal Rural Municipality",
                        "name_nepali": "सायल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "K.I. Singh Rural Municipality",
                        "name_nepali": "के.आई.सिंह गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bogatan Foodsil Rural Municipality",
                        "name_nepali": "बोगटान फुड्सिल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Badi Kedar Rural Municipality",
                        "name_nepali": "बडीकेदार गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jorayal Rural Municipality",
                        "name_nepali": "जोरायल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aadarsha Rural Municipality",
                        "name_nepali": "आदर्श गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shikhar Municipality",
                        "name_nepali": "शिखर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dipayal Silgadhi Municipality",
                        "name_nepali": "दिपायल सिलगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Achham",
                "name_nepali": "अछाम",
                "municipalities": [
                    {
                        "name": "Ramaroshan Rural Municipality",
                        "name_nepali": "रामारोशन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mellekh Rural Municipality",
                        "name_nepali": "मेल्लेख गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sanphebagar Municipality",
                        "name_nepali": "साँफेबगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chaurpati Rural Municipality",
                        "name_nepali": "चौरपाटी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mangalsen Municipality",
                        "name_nepali": "मंगलसेन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kamal Bazar Municipality",
                        "name_nepali": "कमलबजार नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dhakari Rural Municipality",
                        "name_nepali": "ढकारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Turmakhand Rural Municipality",
                        "name_nepali": "तुर्माखाँद गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Panchdebal Binayak Municipality",
                        "name_nepali": "पंचदेवल विनायक नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bannigadhi Jayagadh Rural Municipality",
                        "name_nepali": "बान्नीगढी जयगढ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Kailali",
                "name_nepali": "कैलाली",
                "municipalities": [
                    {
                        "name": "Mohanyal Rural Municipality",
                        "name_nepali": "मोहन्याल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chure Rural Municipality",
                        "name_nepali": "चुरे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Godawari Municipality",
                        "name_nepali": "गोदावरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gauriganga Municipality",
                        "name_nepali": "गौरीगङ्गा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bardagoriya Rural Municipality",
                        "name_nepali": "बर्दगोरिया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lamki Chuha Municipality",
                        "name_nepali": "लम्किचुहा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Janaki Rural Municipality",
                        "name_nepali": "जानकी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Joshipur Rural Municipality",
                        "name_nepali": "जोशीपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tikapur Municipality",
                        "name_nepali": "टीकापुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhajani Municipality",
                        "name_nepali": "भजनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dhangadhi Sub-Metropolitan City",
                        "name_nepali": "धनगढी उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Ghodaghodi Municipality",
                        "name_nepali": "घोडाघोडी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kailari Rural Municipality",
                        "name_nepali": "कैलारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Darchula",
                "name_nepali": "दार्चुला",
                "municipalities": [
                    {
                        "name": "Byas Rural Municipality",
                        "name_nepali": "व्यास गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Duhun Rural Municipality",
                        "name_nepali": "दुहुँ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahakali Municipality",
                        "name_nepali": "महाकाली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Apihimal Rural Municipality",
                        "name_nepali": "अपिहिमाल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Marma Rural Municipality",
                        "name_nepali": "मार्मा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shailyashikhar Municipality",
                        "name_nepali": "शैल्यशिखर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Lekam Rural Municipality",
                        "name_nepali": "लेकम गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Naugad Rural Municipality",
                        "name_nepali": "नौगाड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Malikarjun Rural Municipality",
                        "name_nepali": "मालिकार्जुन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Kanchanpur",
                "name_nepali": "कञ्‍चनपुर",
                "municipalities": [
                    {
                        "name": "Krishnapur Municipality",
                        "name_nepali": "कृष्णपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shuklaphanta Municipality",
                        "name_nepali": "शुक्लाफाटा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bedkot Municipality",
                        "name_nepali": "बेदकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhimdatta Municipality",
                        "name_nepali": "भीमदत्त नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Laljhadi Rural Municipality",
                        "name_nepali": "लालझाडी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Punarbas Municipality",
                        "name_nepali": "पुनर्वास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Belouri Municipality",
                        "name_nepali": "बेलौरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Beldandi Rural Municipality",
                        "name_nepali": "बेलडाँडी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahakali Municipality",
                        "name_nepali": "महाकाली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Madhesh Province",
        "name_nepali": "मधेश प्रदेश",
        "districts": [
            {
                "name": "Saptari",
                "name_nepali": "सप्तरी",
                "municipalities": [
                    {
                        "name": "Saptakoshi Municipality",
                        "name_nepali": "सप्तकोशी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kanchanrup Municipality",
                        "name_nepali": "कञ्चनरुप नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rupani Rural Municipality",
                        "name_nepali": "रुपनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shambhunath Municipality",
                        "name_nepali": "शम्भुनाथ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Surunga Municipality",
                        "name_nepali": "सुरुङ्‍गा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Balan-Bihul Rural Municipality",
                        "name_nepali": "बलान-बिहुल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "BodeBarsain Municipality",
                        "name_nepali": "बोदे बर्साइन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Belhi Chapena Rural Municipality",
                        "name_nepali": "बेल्ही चपेना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bishnupur Rural Municipality",
                        "name_nepali": "बिष्णुपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rajbiraj Municipality",
                        "name_nepali": "राजविराज नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mahadewa Rural Municipality",
                        "name_nepali": "महादेवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tirahut Rural Municipality",
                        "name_nepali": "तिरहुत गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tilathi Koiladi Rural Municipality",
                        "name_nepali": "तिलाठी कोईलाडी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chhinnamasta Rural Municipality",
                        "name_nepali": "छिन्नमस्ता गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Agnisair Krishna Sabaran Rural Municipality",
                        "name_nepali": "अग्निसाइर कृष्णासवरन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khadak Municipality",
                        "name_nepali": "खडक नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dakneshwori Municipality",
                        "name_nepali": "डाक्नेश्वरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Hanumannagar Kankalini Municipality",
                        "name_nepali": "हनुमाननगर कंकालिनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Siraha",
                "name_nepali": "सिराहा",
                "municipalities": [
                    {
                        "name": "Lahan Municipality",
                        "name_nepali": "लहान नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dhangadhimai Municipality",
                        "name_nepali": "धनगढीमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Golbazar Municipality",
                        "name_nepali": "गोलबजार नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mirchaiya Municipality",
                        "name_nepali": "मिर्चैया नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Karjanha Municipality",
                        "name_nepali": "कर्जन्हा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Naraha Rural Municipality",
                        "name_nepali": "नरहा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bishnupur Rural Municipality",
                        "name_nepali": "बिष्णुपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Arnama Rural Municipality",
                        "name_nepali": "अर्नमा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sukhipur Municipality",
                        "name_nepali": "सुखीपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sakhuwa Nankarkatti Rural Municipality",
                        "name_nepali": "सखुवानन्कारकट्टी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhagawanpur Rural Municipality",
                        "name_nepali": "भगवानपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Nawarajpur Rural Municipality",
                        "name_nepali": "नवराजपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bariyarpatti Rural Municipality",
                        "name_nepali": "बरियारपट्टी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aurahi Rural Municipality",
                        "name_nepali": "औरही गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Siraha Municipality",
                        "name_nepali": "सिरहा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kalyanpur Municipality",
                        "name_nepali": "कल्याणपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Laxmipur Patari Rural Municipality",
                        "name_nepali": "लक्ष्मीपुर पटरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Dhanusa",
                "name_nepali": "धनुषा",
                "municipalities": [
                    {
                        "name": "Dhanushadham Municipality",
                        "name_nepali": "धनुषाधाम नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mithila Municipality",
                        "name_nepali": "मिथिला नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bateshwor Rural Municipality",
                        "name_nepali": "बटेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chhireshwornath Municipality",
                        "name_nepali": "क्षिरेश्वरनाथ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Laxminiya Rural Municipality",
                        "name_nepali": "लक्ष्मीनिया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mithila Bihari Municipality",
                        "name_nepali": "मिथिला बिहारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Hansapur Municipality",
                        "name_nepali": "हंसपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shahidnagar Municipality",
                        "name_nepali": "शहीदनगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kamala Municipality",
                        "name_nepali": "कमला नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Janak Nandini Rural Municipality",
                        "name_nepali": "जनकनन्दिनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bideha Municipality",
                        "name_nepali": "विदेह नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Janakpur Sub-Metropolitan City",
                        "name_nepali": "जनकपुरधाम उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Dhanauji Rural Municipality",
                        "name_nepali": "धनौजी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Nagarain Municipality",
                        "name_nepali": "नगराईन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ganeshman Charnath Municipality",
                        "name_nepali": "गणेशमान चारनाथ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sabaila Municipality",
                        "name_nepali": "सबैला नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Aurahi Rural Municipality",
                        "name_nepali": "औरही गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mukhiyapatti Musharniya Rural Municipality",
                        "name_nepali": "मुखियापट्टी मुसहरनिया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Mahottari",
                "name_nepali": "महोत्तरी",
                "municipalities": [
                    {
                        "name": "Bardibas Municipality",
                        "name_nepali": "बर्दिबास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gaushala Municipality",
                        "name_nepali": "गौशाला नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sonama Rural Municipality",
                        "name_nepali": "सोनमा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aurahi Municipality",
                        "name_nepali": "औरही नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Loharpatti Municipality",
                        "name_nepali": "लोहरपट्टी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Balawa Municipality",
                        "name_nepali": "बलवा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ram Gopalpur Municipality",
                        "name_nepali": "रामगोपालपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Samsi Rural Municipality",
                        "name_nepali": "साम्सी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ekadara Rural Municipality",
                        "name_nepali": "एकडारा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahottari Rural Municipality",
                        "name_nepali": "महोत्तरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pipara Rural Municipality",
                        "name_nepali": "पिपरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Matihani Municipality",
                        "name_nepali": "मटिहानी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Jaleshwor Municipality",
                        "name_nepali": "जलेश्वर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhangaha Municipality",
                        "name_nepali": "भँगाहा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Manara Shiswa Municipality",
                        "name_nepali": "मनरा शिसवा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Sarlahi",
                "name_nepali": "सर्लाही",
                "municipalities": [
                    {
                        "name": "Lalbandi Municipality",
                        "name_nepali": "लालबन्दी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bagmati Municipality",
                        "name_nepali": "बागमती नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Barahathawa Municipality",
                        "name_nepali": "बरहथवा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Haripur Municipality",
                        "name_nepali": "हरिपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ishworpur Municipality",
                        "name_nepali": "ईश्वरपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Parsa Rural Municipality",
                        "name_nepali": "पर्सा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Brahmapuri Rural Municipality",
                        "name_nepali": "ब्रह्मपुरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chandranagar Rural Municipality",
                        "name_nepali": "चन्द्रनगर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kabilashi Municipality",
                        "name_nepali": "कविलासी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chakraghatta Rural Municipality",
                        "name_nepali": "चक्रघट्टा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhanakaul Rural Municipality",
                        "name_nepali": "धनकौल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ramnagar Rural Municipality",
                        "name_nepali": "रामनगर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Balara Municipality",
                        "name_nepali": "बलारा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Godaita Municipality",
                        "name_nepali": "गोडैटा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bishnu Rural Municipality",
                        "name_nepali": "विष्णु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Malangawa Municipality",
                        "name_nepali": "मलंगवा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Hariwan Municipality",
                        "name_nepali": "हरिवन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Haripurwa Municipality",
                        "name_nepali": "हरिपुर्वा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Basbariya Rural Municipality",
                        "name_nepali": "बसबरीया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kaudena Rural Municipality",
                        "name_nepali": "कौडेना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Rautahat",
                "name_nepali": "रौतहट",
                "municipalities": [
                    {
                        "name": "Chandrapur Municipality",
                        "name_nepali": "चन्द्रपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gujara Municipality",
                        "name_nepali": "गुजरा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Phatuwa Bijayapur Municipality",
                        "name_nepali": "फतुवाबिजयपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Katahariya Municipality",
                        "name_nepali": "कटहरिया नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Brindaban Municipality",
                        "name_nepali": "बृन्दावन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madhav Narayan Municipality",
                        "name_nepali": "माधव नारायण नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Garuda Municipality",
                        "name_nepali": "गरुडा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dewahi Gonahi Municipality",
                        "name_nepali": "देवाही गोनाही नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Maulapur Municipality",
                        "name_nepali": "मौलापुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Boudhimai Municipality",
                        "name_nepali": "बौधीमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Paroha Municipality",
                        "name_nepali": "परोहा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Yamunamai Rural Municipality",
                        "name_nepali": "यमुनामाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rajdevi Municipality",
                        "name_nepali": "राजदेवी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gaur Municipality",
                        "name_nepali": "गौर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ishanath Municipality",
                        "name_nepali": "ईशनाथ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gadhimai Municipality",
                        "name_nepali": "गढीमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rajpur Municipality",
                        "name_nepali": "राजपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Durga Bhagawati Rural Municipality",
                        "name_nepali": "दुर्गा भगवती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Bara",
                "name_nepali": "बारा",
                "municipalities": [
                    {
                        "name": "Nijagadh Municipality",
                        "name_nepali": "निजगढ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kolhabi Municipality",
                        "name_nepali": "कोल्हवी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Parawanipur Rural Municipality",
                        "name_nepali": "परवानीपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Prasauni Rural Municipality",
                        "name_nepali": "प्रसौनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bishrampur Rural Municipality",
                        "name_nepali": "विश्रामपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pheta Rural Municipality",
                        "name_nepali": "फेटा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kalaiya Sub-Metropolitan City",
                        "name_nepali": "कलैया उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Karaiyamai Rural Municipality",
                        "name_nepali": "करैयामाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aadarsha Kotwal Rural Municipality",
                        "name_nepali": "आदर्श कोटवाल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Simroungadh Municipality",
                        "name_nepali": "सिम्रौनगढ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Pacharauta Municipality",
                        "name_nepali": "पचरौता नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mahagadhimai Municipality",
                        "name_nepali": "महागढीमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Devtal Rural Municipality",
                        "name_nepali": "देवताल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jitpur Simara Sub-Metropolitan City",
                        "name_nepali": "जीतपुर सिमरा उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Baragadhi Rural Municipality",
                        "name_nepali": "बारागढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Subarna Rural Municipality",
                        "name_nepali": "सुवर्ण गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Parsa",
                "name_nepali": "पर्सा",
                "municipalities": [
                    {
                        "name": "Thori Rural Municipality",
                        "name_nepali": "ठोरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jirabhawani Rural Municipality",
                        "name_nepali": "जिराभवानी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jagarnathpur Rural Municipality",
                        "name_nepali": "जगरनाथपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sakhuwa Prasauni Rural Municipality",
                        "name_nepali": "सखुवा प्रसौनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Parsagadhi Municipality",
                        "name_nepali": "पर्सागढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Birgunj Metropolitan City",
                        "name_nepali": "वीरगंज महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Bahudarmai Municipality",
                        "name_nepali": "बहुदरमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Pokhariya Municipality",
                        "name_nepali": "पोखरि नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kalikamai Rural Municipality",
                        "name_nepali": "कालिकामाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhobini Rural Municipality",
                        "name_nepali": "धोबीनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pakaha Mainpur Rural Municipality",
                        "name_nepali": "पकहाँ मैनपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bindabasini Rural Municipality",
                        "name_nepali": "बिन्दबासिनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Paterwa Sugauli Rural Municipality",
                        "name_nepali": "पटेर्वा सुगौली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chhipaharmai Rural Municipality",
                        "name_nepali": "छिपहरमाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Gandaki Province",
        "name_nepali": "गण्डकी प्रदेश",
        "districts": [
            {
                "name": "Gorkha",
                "name_nepali": "गोरखा",
                "municipalities": [
                    {
                        "name": "Chumanubri Rural Municipality",
                        "name_nepali": "चुमनुव्री गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sulikot Rural Municipality",
                        "name_nepali": "बारपाक सुलिकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dharche Rural Municipality",
                        "name_nepali": "धार्चे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aarughat Rural Municipality",
                        "name_nepali": "आरूघाट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhimsen Rural Municipality",
                        "name_nepali": "भिमसेनथापा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Siranchowk Rural Municipality",
                        "name_nepali": "सिरानचोक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gorkha Municipality",
                        "name_nepali": "गोरखा Municipality",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shahid Lakhan Rural Municipality",
                        "name_nepali": "शहिद लखन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gandaki Rural Municipality",
                        "name_nepali": "गण्डकी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ajirkot Rural Municipality",
                        "name_nepali": "अजिरकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Palungtar Municipality",
                        "name_nepali": "पालुङटार नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Manang",
                "name_nepali": "मनाङ",
                "municipalities": [
                    {
                        "name": "Narpa Bhumi Rural Municipality",
                        "name_nepali": "नार्पा भूमि गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chame Rural Municipality",
                        "name_nepali": "चाँमे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Nashong Rural Municipality",
                        "name_nepali": "नासाेँ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Neshang Rural Municipality",
                        "name_nepali": "मनाङ ङिस्याङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Mustang",
                "name_nepali": "मुस्ताङ",
                "municipalities": [
                    {
                        "name": "Dalome Rural Municipality",
                        "name_nepali": "दालोमे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gharpajhong Rural Municipality",
                        "name_nepali": "घरपझोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lomanthang Rural Municipality",
                        "name_nepali": "लोमन्थाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thasang Rural Municipality",
                        "name_nepali": "थासाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bahragaun Muktikshetra Rural Municipality",
                        "name_nepali": "वारागुङ मुक्तिक्षेत्रगाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Myagdi",
                "name_nepali": "म्याग्दी",
                "municipalities": [
                    {
                        "name": "Annapurna Rural Municipality",
                        "name_nepali": "अन्नपूर्ण गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Raghuganga Rural Municipality",
                        "name_nepali": "रघुगंगा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhawalagiri Rural Municipality",
                        "name_nepali": "धवलागिरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Malika Rural Municipality",
                        "name_nepali": "मालिका गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mangala Rural Municipality",
                        "name_nepali": "मंगला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Beni Municipality",
                        "name_nepali": "बेनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Kaski",
                "name_nepali": "कास्की",
                "municipalities": [
                    {
                        "name": "Madi Rural Municipality",
                        "name_nepali": "मादी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Annapurna Rural Municipality",
                        "name_nepali": "माछापुच्छ्रे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pokhara Metropolitan City",
                        "name_nepali": "पोखरा महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Rupa Rural Municipality",
                        "name_nepali": "रूपा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Machhapuchchhre Rural Municipality",
                        "name_nepali": "माछापुच्छ्रे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Lamjung",
                "name_nepali": "लमजुङ",
                "municipalities": [
                    {
                        "name": "Dordi Rural Municipality",
                        "name_nepali": "दोर्दी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Marshyangdi Rural Municipality",
                        "name_nepali": "मर्स्याङदी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Madhya Nepal Municipality",
                        "name_nepali": "मध्यनेपाल नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bensi Shahar Municipality",
                        "name_nepali": "बेसीशहर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rainas Municipality",
                        "name_nepali": "राईनास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kwhola Sothar Rural Municipality",
                        "name_nepali": "क्व्होलासोथार गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sundarbazar Municipality",
                        "name_nepali": "सुन्दरबजार नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dudhapokhari Rural Municipality",
                        "name_nepali": "दूधपोखरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Tanahu",
                "name_nepali": "तनहुँ",
                "municipalities": [
                    {
                        "name": "Bhanu Municipality",
                        "name_nepali": "भानु नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Byas Municipality",
                        "name_nepali": "व्यास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Myagde Rural Municipality",
                        "name_nepali": "म्याग्दे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shuklagandaki Municipality",
                        "name_nepali": "शुक्लागण्डकी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhimad Municipality",
                        "name_nepali": "भिमाद नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ghiring Rural Municipality",
                        "name_nepali": "घिरिङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Devghat Rural Municipality",
                        "name_nepali": "देवघाट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bandipur Rural Municipality",
                        "name_nepali": "बन्दिपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aanbookhaireni Rural Municipality",
                        "name_nepali": "आँबूखैरेनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rhishing Rural Municipality",
                        "name_nepali": "ऋषिङ्ग गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Nawalparasi East",
                "name_nepali": "नवलपरासी पूर्व",
                "municipalities": [
                    {
                        "name": "Gaidakot Municipality",
                        "name_nepali": "गैंडाकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bulingtar Rural Municipality",
                        "name_nepali": "बुलिङटार गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Hupsekot Rural Municipality",
                        "name_nepali": "हुप्सेकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Devchuli Municipality",
                        "name_nepali": "देवचुली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kawasoti Municipality",
                        "name_nepali": "कावासोती नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madhyabindu Municipality",
                        "name_nepali": "मध्यविन्दु नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Binayi Tribeni Rural Municipality",
                        "name_nepali": "विनयी त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bungdikali Rural Municipality",
                        "name_nepali": "बौदीकाली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Syangja",
                "name_nepali": "स्याङ्जा",
                "municipalities": [
                    {
                        "name": "Phedikhola Rural Municipality",
                        "name_nepali": "फेदीखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aandhikhola Rural Municipality",
                        "name_nepali": "आँधिखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Arjun Choupari Rural Municipality",
                        "name_nepali": "अर्जुनचौपारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhirkot Municipality",
                        "name_nepali": "भीरकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Biruwa Rural Municipality",
                        "name_nepali": "विरुवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chapakot Municipality",
                        "name_nepali": "चापाकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Walling Municipality",
                        "name_nepali": "वालिङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Galyang Municipality",
                        "name_nepali": "गल्याङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kaligandaki Rural Municipality",
                        "name_nepali": "कालीगण्डकी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Putalibazar Municipality",
                        "name_nepali": "पुतलीबजार नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Harinas Rural Municipality",
                        "name_nepali": "हरिनास गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Parbat",
                "name_nepali": "पर्वत",
                "municipalities": [
                    {
                        "name": "Modi Rural Municipality",
                        "name_nepali": "मोदी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kushma Municipality",
                        "name_nepali": "कुश्मा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Phalebas Municipality",
                        "name_nepali": "फलेवास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mahashila Rural Municipality",
                        "name_nepali": "महाशिला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bihadi Rural Municipality",
                        "name_nepali": "विहादी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Paiyu Rural Municipality",
                        "name_nepali": "पैयूँ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jaljala Rural Municipality",
                        "name_nepali": "जलजला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Baglung",
                "name_nepali": "बाग्लुङ",
                "municipalities": [
                    {
                        "name": "Baglung Municipality",
                        "name_nepali": "बाग्लुङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tarakhola Rural Municipality",
                        "name_nepali": "ताराखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tamankhola Rural Municipality",
                        "name_nepali": "तमानखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhorpatan Municipality",
                        "name_nepali": "ढोरपाटन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Nisikhola Rural Municipality",
                        "name_nepali": "निसीखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Badigad Rural Municipality",
                        "name_nepali": "वडिगाड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Galkot Municipality",
                        "name_nepali": "गल्कोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Jaimuni Municipality",
                        "name_nepali": "जैमिनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kathekhola Rural Municipality",
                        "name_nepali": "काठेखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bareng Rural Municipality",
                        "name_nepali": "बरेङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Bagmati Province",
        "name_nepali": "बागमती प्रदेश",
        "districts": [
            {
                "name": "Dolakha",
                "name_nepali": "दोलखा",
                "municipalities": [
                    {
                        "name": "Gaurishankar Rural Municipality",
                        "name_nepali": "गौरीशंकर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bigu Rural Municipality",
                        "name_nepali": "विगु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kalinchowk Rural Municipality",
                        "name_nepali": "कालिन्चोक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jiri Municipality",
                        "name_nepali": "जिरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tamakoshi Rural Municipality",
                        "name_nepali": "तामाकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Melung Rural Municipality",
                        "name_nepali": "मेलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shailung Rural Municipality",
                        "name_nepali": "शैलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhimeshwor Municipality",
                        "name_nepali": "भीमेश्वर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Baitedhar Rural Municipality",
                        "name_nepali": "वैतेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Sindhupalchok",
                "name_nepali": "सिन्धुपाल्चोक",
                "municipalities": [
                    {
                        "name": "Jugal Rural Municipality",
                        "name_nepali": "जुगल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Panchpokhari Thangpal Rural Municipality",
                        "name_nepali": "पाँचपोखरी थाङपाल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Helambu Rural Municipality",
                        "name_nepali": "हेलम्बु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Choutara Sangachowkgadhi Municipality",
                        "name_nepali": "चौतारा साँगाचोकगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Balephi Rural Municipality",
                        "name_nepali": "बलेफी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bahrabise Municipality",
                        "name_nepali": "बाह्रविसे नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Lisankhu Pakhar Rural Municipality",
                        "name_nepali": "लिसंखु पाखर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunkoshi Rural Municipality",
                        "name_nepali": "सुनकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhotekoshi Rural Municipality",
                        "name_nepali": "भोटेकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Melanchi Municipality",
                        "name_nepali": "मेलम्ची नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Indrawoti Rural Municipality",
                        "name_nepali": "ईन्द्रावती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tripurasundari Rural Municipality",
                        "name_nepali": "त्रिपुरासुन्दरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Rasuwa",
                "name_nepali": "रसुवा",
                "municipalities": [
                    {
                        "name": "Gosaikunda Rural Municipality",
                        "name_nepali": "गोसाईकुण्ड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aama Chhodingmo Rural Municipality",
                        "name_nepali": "आमाछोदिङ्मो गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Uttargaya Rural Municipality",
                        "name_nepali": "उत्तरगया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kalika Rural Municipality",
                        "name_nepali": "कालिका गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Naukunda Rural Municipality",
                        "name_nepali": "नौकुण्ड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Dhading",
                "name_nepali": "धादिङ",
                "municipalities": [
                    {
                        "name": "Khaniyabas Rural Municipality",
                        "name_nepali": "खनियाबास गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ganga Jamuna Rural Municipality",
                        "name_nepali": "गंगाजमुना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tripurasundari Rural Municipality",
                        "name_nepali": "त्रिपुरासुन्दरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Netrawati Rural Municipality",
                        "name_nepali": "नेत्रावती डबजोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Neelakantha Municipality",
                        "name_nepali": "नीलकण्ठ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Siddhalek Rural Municipality",
                        "name_nepali": "सिद्धलेक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Benighat Rorang Rural Municipality",
                        "name_nepali": "वेनीघाट रोराङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gajuri Rural Municipality",
                        "name_nepali": "गजुरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Galchhi Rural Municipality",
                        "name_nepali": "गल्छी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thakre Rural Municipality",
                        "name_nepali": "थाक्रे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhunibenshi Municipality",
                        "name_nepali": "धुनिवेशी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rubi Valley Rural Municipality",
                        "name_nepali": "रुबी भ्याली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jwalamukhi Rural Municipality",
                        "name_nepali": "ज्वालामूखी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Nuwakot",
                "name_nepali": "नुवाकोट",
                "municipalities": [
                    {
                        "name": "Tadi Rural Municipality",
                        "name_nepali": "तादी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Suryagadhi Rural Municipality",
                        "name_nepali": "सुर्यगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bidur Municipality",
                        "name_nepali": "विदुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kispang Rural Municipality",
                        "name_nepali": "किस्पाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Meghang Rural Municipality",
                        "name_nepali": "म्यागङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Belkotgadhi Municipality",
                        "name_nepali": "बेलकोटगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Likhu Rural Municipality",
                        "name_nepali": "लिखु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Panchakanya Rural Municipality",
                        "name_nepali": "पञ्चकन्या गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shivapuri Rural Municipality",
                        "name_nepali": "शिवपुरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kakani Rural Municipality",
                        "name_nepali": "ककनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dupcheshwor Rural Municipality",
                        "name_nepali": "दुप्चेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tarakeshwor Rural Municipality",
                        "name_nepali": "तारकेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Kathmandu",
                "name_nepali": "काठमाडौं",
                "municipalities": [
                    {
                        "name": "Kageshwori Manahara Municipality",
                        "name_nepali": "कागेश्वरी मनोहरा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gokarneshwor Municipality",
                        "name_nepali": "गोकर्णेश्वर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Budhanilkhantha Municipality",
                        "name_nepali": "बूढानीलकण्ठ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tokha Municipality",
                        "name_nepali": "टोखा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tarakeshwor Municipality",
                        "name_nepali": "तारकेश्वर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Nagarjun Municipality",
                        "name_nepali": "नागार्जुन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kirtipur Municipality",
                        "name_nepali": "कीर्तिपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dakshinkali Municipality",
                        "name_nepali": "दक्षिणकाली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shankharapur Municipality",
                        "name_nepali": "शङ्खरापुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kathmandu Metropolitan City",
                        "name_nepali": "काठमाडौँ महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Chandragiri Municipality",
                        "name_nepali": "चन्द्रागिरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Bhaktapur",
                "name_nepali": "भक्तपुर",
                "municipalities": [
                    {
                        "name": "Bhaktapur Municipality",
                        "name_nepali": "भक्तपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madhyapur Thimi Municipality",
                        "name_nepali": "मध्यपुर थिमि नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Suryabinayak Municipality",
                        "name_nepali": "सूर्यविनायक नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Changunarayan Municipality",
                        "name_nepali": "चाँगुनारायण नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Lalitpur",
                "name_nepali": "ललितपुर",
                "municipalities": [
                    {
                        "name": "Mahalaxmi Municipality",
                        "name_nepali": "महालक्ष्मी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Lalitpur Metropolitan City",
                        "name_nepali": "ललितपुर महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Godawari Municipality",
                        "name_nepali": "गोदावरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mahankal Rural Municipality",
                        "name_nepali": "महाङ्काल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bagmati Rural Municipality",
                        "name_nepali": "वाग्मती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Konjyosom Rural Municipality",
                        "name_nepali": "कोन्ज्योसोम गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Kavrepalanchok",
                "name_nepali": "काभ्रेपलान्चोक",
                "municipalities": [
                    {
                        "name": "Chauri Deurali Rural Municipality",
                        "name_nepali": "चौंरीदेउराली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhumlu Rural Municipality",
                        "name_nepali": "भुम्लु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mandan Deupur Municipality",
                        "name_nepali": "मण्डनदेउपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Banepa Municipality",
                        "name_nepali": "बनेपा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Panchkhal Municipality",
                        "name_nepali": "पाँचखाल नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Temal Rural Municipality",
                        "name_nepali": "तेमाल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Namobuddha Municipality",
                        "name_nepali": "नमोबुद्ध नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Panauti Municipality",
                        "name_nepali": "पनौती नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Roshi Rural Municipality",
                        "name_nepali": "रोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahabharat Rural Municipality",
                        "name_nepali": "महाभारत गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khanikhola Rural Municipality",
                        "name_nepali": "खानीखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhulikhel Municipality",
                        "name_nepali": "धुलिखेल नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bethanchowk Rural Municipality",
                        "name_nepali": "बेथानचोक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Ramechhap",
                "name_nepali": "रामेछाप",
                "municipalities": [
                    {
                        "name": "Umakunda Rural Municipality",
                        "name_nepali": "उमाकुण्ड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gokulganga Rural Municipality",
                        "name_nepali": "गोकुलगंगा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Likhu Rural Municipality",
                        "name_nepali": "लिखु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Manthali Municipality",
                        "name_nepali": "मन्थली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Khandadevi Rural Municipality",
                        "name_nepali": "खाँडादेवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Doramba Rural Municipality",
                        "name_nepali": "दोरम्बा शैलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunapati Rural Municipality",
                        "name_nepali": "सुनापति गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ramechhap Municipality",
                        "name_nepali": "रामेछाप नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Sindhuli",
                "name_nepali": "सिन्धुली",
                "municipalities": [
                    {
                        "name": "Dudhouli Municipality",
                        "name_nepali": "दुधौली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tinpatan Rural Municipality",
                        "name_nepali": "तीनपाटन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Golanjor Rural Municipality",
                        "name_nepali": "गोलन्जोर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kamalamai Municipality",
                        "name_nepali": "कमलामाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sunkoshi Rural Municipality",
                        "name_nepali": "सुनकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Marin Rural Municipality",
                        "name_nepali": "मरिण गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Hariharpurgaghi Rural Municipality",
                        "name_nepali": "हरिहरपुरगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Phikkal Rural Municipality",
                        "name_nepali": "फिक्कल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ghyanglekha Rural Municipality",
                        "name_nepali": "घ्याङलेख गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Makwanpur",
                "name_nepali": "मकवानपुर",
                "municipalities": [
                    {
                        "name": "Indrasarowar Rural Municipality",
                        "name_nepali": "इन्द्रसरोवर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thaha Municipality",
                        "name_nepali": "थाहा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kailash Rural Municipality",
                        "name_nepali": "कैलाश गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Manahari Rural Municipality",
                        "name_nepali": "मनहरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Hetauda Sub-Metropolitan City",
                        "name_nepali": "हेटौडा उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Makawanpurgadhi Rural Municipality",
                        "name_nepali": "मकवानपुरगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bakaiya Rural Municipality",
                        "name_nepali": "बकैया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bagmati Rural Municipality",
                        "name_nepali": "बागमती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Raksirang Rural Municipality",
                        "name_nepali": "राक्सिराङ्ग गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhimphedi Rural Municipality",
                        "name_nepali": "भीमफेदी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Chitawan",
                "name_nepali": "चितवन",
                "municipalities": [
                    {
                        "name": "Rapti Municipality",
                        "name_nepali": "राप्ती नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kalika Municipality",
                        "name_nepali": "कालिका नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bharatpur Metropolitan City",
                        "name_nepali": "भरतपुर महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Ratnanagar Municipality",
                        "name_nepali": "रत्ननगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Khairahani Municipality",
                        "name_nepali": "खैरहनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madi Municipality",
                        "name_nepali": "माडी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ichchha Kamana Rural Municipality",
                        "name_nepali": "इच्छाकामना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Lumbini Province",
        "name_nepali": "लुम्बिनी प्रदेश",
        "districts": [
            {
                "name": "Rukum East",
                "name_nepali": "रूकुम पूर्व",
                "municipalities": [
                    {
                        "name": "Sisne Rural Municipality",
                        "name_nepali": "सिस्ने गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhoome Rural Municipality",
                        "name_nepali": "भूमे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Putha Uttanganga Rural Municipality",
                        "name_nepali": "पुथा उत्तरगंगा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Rolpa",
                "name_nepali": "रोल्पा",
                "municipalities": [
                    {
                        "name": "Sunchhahari Rural Municipality",
                        "name_nepali": "सुनछहरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thawang Rural Municipality",
                        "name_nepali": "थबाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Duikholi Rural Municipality",
                        "name_nepali": "दुईखोली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Madi Rural Municipality",
                        "name_nepali": "मादी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tribeni Rural Municipality",
                        "name_nepali": "त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rolpa Municipality",
                        "name_nepali": "रोल्पा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Runtigadhi Rural Municipality",
                        "name_nepali": "रुन्टीगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunilsmiriti Rural Municipality",
                        "name_nepali": "सुनिलस्मृति गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lungri Rural Municipality",
                        "name_nepali": "लुङग्री गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gangadev Rural Municipality",
                        "name_nepali": "गङ्गादेव गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Pyuthan",
                "name_nepali": "प्युठान",
                "municipalities": [
                    {
                        "name": "Naubahini Rural Municipality",
                        "name_nepali": "नौबहिनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jhimaruk Rural Municipality",
                        "name_nepali": "झिमरुक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pyuthan Municipality",
                        "name_nepali": "प्यूठान नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sworgadwari Municipality",
                        "name_nepali": "स्वर्गद्वारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mandavi Rural Municipality",
                        "name_nepali": "माण्डवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aairawati Rural Municipality",
                        "name_nepali": "ऐरावती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sarumarani Rural Municipality",
                        "name_nepali": "सरुमारानी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gaumukhi Rural Municipality",
                        "name_nepali": "गौमुखी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mallarani Rural Municipality",
                        "name_nepali": "मल्लरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Gulmi",
                "name_nepali": "गुल्मी",
                "municipalities": [
                    {
                        "name": "Kali Gandaki Rural Municipality",
                        "name_nepali": "कालीगण्डकी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Satyawoti Rural Municipality",
                        "name_nepali": "सत्यवती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Musikot Municipality",
                        "name_nepali": "मुसिकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Isma Rural Municipality",
                        "name_nepali": "इस्मा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Malika Rural Municipality",
                        "name_nepali": "मालिका गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Madane Rural Municipality",
                        "name_nepali": "मदाने गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhurkot Rural Municipality",
                        "name_nepali": "धुर्कोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Resunga Municipality",
                        "name_nepali": "रेसुङ्गा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhatrakot Rural Municipality",
                        "name_nepali": "छत्रकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ruru Rural Municipality",
                        "name_nepali": "रुरुक्षेत्र गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chandrakot Rural Municipality",
                        "name_nepali": "चन्द्रकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gulmi Durbar Rural Municipality",
                        "name_nepali": "गुल्मी दरबार गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Arghakhanchi",
                "name_nepali": "अर्घाखाँची",
                "municipalities": [
                    {
                        "name": "Chhatradev Rural Municipality",
                        "name_nepali": "छत्रदेव गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Malarani Rural Municipality",
                        "name_nepali": "मालारानी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhumikasthan Municipality",
                        "name_nepali": "भुमिकास्थान नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sandhikharka Municipality",
                        "name_nepali": "सन्धिखर्क नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shitaganga Municipality",
                        "name_nepali": "शितगंगा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Panini Rural Municipality",
                        "name_nepali": "पाणिनी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Palpa",
                "name_nepali": "पाल्पा",
                "municipalities": [
                    {
                        "name": "Rampur Municipality",
                        "name_nepali": "रामपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Purbakhola Rural Municipality",
                        "name_nepali": "पूर्वखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rambha Rural Municipality",
                        "name_nepali": "रम्भा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Baganaskali Rural Municipality",
                        "name_nepali": "बगनासकाली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tansen Municipality",
                        "name_nepali": "तानसेन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rainadevi Chhahara Rural Municipality",
                        "name_nepali": "रैनादेवी छहरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mathagadhi Rural Municipality",
                        "name_nepali": "माथागढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ribdikot Rural Municipality",
                        "name_nepali": "रिब्दीकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tinau Rural Municipality",
                        "name_nepali": "तिनाउ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Nisdi Rural Municipality",
                        "name_nepali": "निस्दी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Rupandehi",
                "name_nepali": "रुपन्देही",
                "municipalities": [
                    {
                        "name": "Devdaha Municipality",
                        "name_nepali": "देवदह नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Butwal Sub-Metropolitan City",
                        "name_nepali": "बुटवल उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Sainamaina Municipality",
                        "name_nepali": "सैनामैना नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kanchan Rural Municipality",
                        "name_nepali": "कञ्चन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Suddhodhan Rural Municipality",
                        "name_nepali": "शुद्धोधन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Siyari Rural Municipality",
                        "name_nepali": "सियारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tilottama Municipality",
                        "name_nepali": "तिलोत्तमा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Om Satiya Rural Municipality",
                        "name_nepali": "ओमसतिया गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rohini Rural Municipality",
                        "name_nepali": "रोहिणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mayadevi Rural Municipality",
                        "name_nepali": "मायादेवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lumbini Sanskritik Municipality",
                        "name_nepali": "लुम्बिनी साँस्कृतिक नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kotahimai Rural Municipality",
                        "name_nepali": "कोटहीमाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sammarimai Rural Municipality",
                        "name_nepali": "सम्मरीमाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Marchawari Rural Municipality",
                        "name_nepali": "मर्चवारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gaidahawa Rural Municipality",
                        "name_nepali": "गैडहवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Siddharthanagar Municipality",
                        "name_nepali": "सिद्धार्थनगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Kapilvastu",
                "name_nepali": "कपिलवस्तु",
                "municipalities": [
                    {
                        "name": "Banganga Municipality",
                        "name_nepali": "वाणगङ्गा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shivaraj Municipality",
                        "name_nepali": "शिवराज नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bijayanagar Rural Municipality",
                        "name_nepali": "विजयनगर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Krishnanagar Municipality",
                        "name_nepali": "कृष्णनगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Maharajganj Municipality",
                        "name_nepali": "महाराजगंज नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Yasodhara Rural Municipality",
                        "name_nepali": "यसोधरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mayadevi Rural Municipality",
                        "name_nepali": "मायादेवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shuddhodhan Rural Municipality",
                        "name_nepali": "शुद्धोधन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Buddhabhumi Municipality",
                        "name_nepali": "बुद्धभूमि नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kapilvastu Municipality",
                        "name_nepali": "कपिलवस्तु नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Dang",
                "name_nepali": "दाङ",
                "municipalities": [
                    {
                        "name": "Bangalachuli Rural Municipality",
                        "name_nepali": "बंगलाचुली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tulsipur Sub-Metropolitan City",
                        "name_nepali": "तुलसीपुर उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Shantinagar Rural Municipality",
                        "name_nepali": "शान्तिनगर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Babai Rural Municipality",
                        "name_nepali": "बबई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dangisharan Rural Municipality",
                        "name_nepali": "दंगीशरण गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lamahi Municipality",
                        "name_nepali": "लमही नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ghorahi Sub-Metropolitan City",
                        "name_nepali": "घोराही उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Rapti Rural Municipality",
                        "name_nepali": "राप्ती गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gadhawa Rural Municipality",
                        "name_nepali": "गढवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rajpur Rural Municipality",
                        "name_nepali": "राजपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Banke",
                "name_nepali": "बाँके",
                "municipalities": [
                    {
                        "name": "Khajura Rural Municipality",
                        "name_nepali": "खजुरा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Janaki Rural Municipality",
                        "name_nepali": "जानकी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rapti Sonari Rural Municipality",
                        "name_nepali": "राप्ती सोनारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kohalpur Municipality",
                        "name_nepali": "कोहलपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Baijanath Rural Municipality",
                        "name_nepali": "बैजनाथ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Nepalgunj Sub-Metropolitan City",
                        "name_nepali": "नेपालगन्ज उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Duduwa Rural Municipality",
                        "name_nepali": "डुडुवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Narainapur Rural Municipality",
                        "name_nepali": "नरैनापुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Bardiya",
                "name_nepali": "बर्दिया",
                "municipalities": [
                    {
                        "name": "Thakurbaba Municipality",
                        "name_nepali": "ठाकुरबाबा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Geruwa Rural Municipality",
                        "name_nepali": "गेरुवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Rajapur Municipality",
                        "name_nepali": "राजापुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madhuwan Municipality",
                        "name_nepali": "मधुवन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bansgadhi Municipality",
                        "name_nepali": "बाँसगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Barbardiya Municipality",
                        "name_nepali": "बारबर्दिया नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gulariya Municipality",
                        "name_nepali": "गुलरिया नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Badhaiyatal Rural Municipality",
                        "name_nepali": "बढैयाताल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Nawalparasi West",
                "name_nepali": "नवलपरासी पश्चिम",
                "municipalities": [
                    {
                        "name": "Bardaghat Municipality",
                        "name_nepali": "बर्दघाट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sunawal Municipality",
                        "name_nepali": "सुनवल नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ramgram Municipality",
                        "name_nepali": "रामग्राम नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Palhinandan Rural Municipality",
                        "name_nepali": "पाल्हीनन्दन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sarawal Rural Municipality",
                        "name_nepali": "सरावल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Susta Rural Municipality",
                        "name_nepali": "सुस्ता गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pratapapur Rural Municipality",
                        "name_nepali": "प्रतापपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Karnali Province",
        "name_nepali": "कर्णाली प्रदेश",
        "districts": [
            {
                "name": "Dolpa",
                "name_nepali": "डोल्पा",
                "municipalities": [
                    {
                        "name": "Mudkechula Rural Municipality",
                        "name_nepali": "मुड्केचुला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tripurasundari Municipality",
                        "name_nepali": "त्रिपुरासुन्दरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Thulibheri Municipality",
                        "name_nepali": "ठुली भेरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kaike Rural Municipality",
                        "name_nepali": "काईके गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chharka Tangsong Rural Municipality",
                        "name_nepali": "छार्का ताङसोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Shey Phoksundo Rural Municipality",
                        "name_nepali": "शे फोक्सुण्डो गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jagadulla Rural Municipality",
                        "name_nepali": "जगदुल्ला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dolpo Buddha Rural Municipality",
                        "name_nepali": "डोल्पो बुद्ध गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Mugu",
                "name_nepali": "मुगु",
                "municipalities": [
                    {
                        "name": "Mugumakarmarog Rural Municipality",
                        "name_nepali": "मुगूम कार्मारोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chhayanath Rara Municipality",
                        "name_nepali": "छायाँनाथ रारा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Khatyad Rural Municipality",
                        "name_nepali": "खत्याड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Soru Rural Municipality",
                        "name_nepali": "सोरु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Jumla",
                "name_nepali": "जुम्ला",
                "municipalities": [
                    {
                        "name": "Patarasi Rural Municipality",
                        "name_nepali": "पातारासी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kanaka Sundari Rural Municipality",
                        "name_nepali": "कनकासुन्दरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sinja Rural Municipality",
                        "name_nepali": "सिंजा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chandannath Municipality",
                        "name_nepali": "चन्दननाथ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Guthichaur Rural Municipality",
                        "name_nepali": "गुठिचौर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tatopani Rural Municipality",
                        "name_nepali": "तातोपानी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tila Rural Municipality",
                        "name_nepali": "तिला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Hima Rural Municipality",
                        "name_nepali": "हिमा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Kalikot",
                "name_nepali": "कालिकोट",
                "municipalities": [
                    {
                        "name": "Mahawai Rural Municipality",
                        "name_nepali": "महावै गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kalika Rural Municipality",
                        "name_nepali": "कालिका गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Palata Rural Municipality",
                        "name_nepali": "पलाँता गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pachal Jharana Rural Municipality",
                        "name_nepali": "पचालझरना गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Raskot Municipality",
                        "name_nepali": "रास्कोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sanni Tribeni Rural Municipality",
                        "name_nepali": "सान्नी त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Naraharinath Rural Municipality",
                        "name_nepali": "नरहरिनाथ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khandachakra Municipality",
                        "name_nepali": "खाँडाचक्र नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tilagupha Municipality",
                        "name_nepali": "तिलागुफा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Dailekh",
                "name_nepali": "दैलेख",
                "municipalities": [
                    {
                        "name": "Naumule Rural Municipality",
                        "name_nepali": "नौमुले गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahabu Rural Municipality",
                        "name_nepali": "महाबु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhairabi Rural Municipality",
                        "name_nepali": "भैरवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Thantikandh Rural Municipality",
                        "name_nepali": "ठाटीकाँध गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aathbis Municipality",
                        "name_nepali": "आठबीस नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chamunda Bindrasaini Municipality",
                        "name_nepali": "चामुण्डा बिन्द्रासैनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dullu Municipality",
                        "name_nepali": "दुल्लू नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Narayan Municipality",
                        "name_nepali": "नारायण नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bhagawatimai Rural Municipality",
                        "name_nepali": "भगवतीमाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dungeshwor Rural Municipality",
                        "name_nepali": "डुङ्गेश्वर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gurans Rural Municipality",
                        "name_nepali": "गुराँस गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Jajarkot",
                "name_nepali": "जाजरकोट",
                "municipalities": [
                    {
                        "name": "Shivalaya Rural Municipality",
                        "name_nepali": "शिवालय गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bheri Municipality",
                        "name_nepali": "भेरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tribeni Nalagad Municipality",
                        "name_nepali": "त्रिवेणी नलगाड नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Barekot Rural Municipality",
                        "name_nepali": "बारेकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kuse Rural Municipality",
                        "name_nepali": "कुसे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Junichande Rural Municipality",
                        "name_nepali": "जुनीचाँदे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chhedagad Municipality",
                        "name_nepali": "छेडागाड नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Salyan",
                "name_nepali": "सल्यान",
                "municipalities": [
                    {
                        "name": "Darma Rural Municipality",
                        "name_nepali": "दार्मा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kumakh Malika Rural Municipality",
                        "name_nepali": "कुमाख गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Banagad Kupinde Municipality",
                        "name_nepali": "बनगाड कुपिण्डे नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dhorchaur Rural Municipality",
                        "name_nepali": "ढोरचौर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bagachour Municipality",
                        "name_nepali": "बागचौर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhatreshwori Rural Municipality",
                        "name_nepali": "छत्रेश्वरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sharada Municipality",
                        "name_nepali": "शारदा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kalimati Rural Municipality",
                        "name_nepali": "कालिमाटी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tribeni Rural Municipality",
                        "name_nepali": "त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kapurkot Rural Municipality",
                        "name_nepali": "कपुरकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Surkhet",
                "name_nepali": "सुर्खेत",
                "municipalities": [
                    {
                        "name": "Simta Rural Municipality",
                        "name_nepali": "सिम्ता गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chingad Rural Municipality",
                        "name_nepali": "चिङ्गाड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lekabeshi Municipality",
                        "name_nepali": "लेकबेशी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gurbhakot Municipality",
                        "name_nepali": "गुर्भाकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Bheriganga Municipality",
                        "name_nepali": "भेरीगंगा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Birendranagar Municipality",
                        "name_nepali": "वीरेन्द्रनगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Barahatal Rural Municipality",
                        "name_nepali": "बराहताल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Panchapuri Municipality",
                        "name_nepali": "पञ्चपुरी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chaukune Rural Municipality",
                        "name_nepali": "चौकुने गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Humla",
                "name_nepali": "हुम्ला",
                "municipalities": [
                    {
                        "name": "Chankheli Rural Municipality",
                        "name_nepali": "चंखेली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kharpunath Rural Municipality",
                        "name_nepali": "खार्पूनाथ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Simkot Rural Municipality",
                        "name_nepali": "सिमकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Namkha Rural Municipality",
                        "name_nepali": "नाम्खा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sarkegad Rural Municipality",
                        "name_nepali": "सर्केगाड गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Adanchuli Rural Municipality",
                        "name_nepali": "अदानचुली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tanjakot Rural Municipality",
                        "name_nepali": "ताँजाकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Rukum West",
                "name_nepali": "रूकुम पश्चिम",
                "municipalities": [
                    {
                        "name": "Aathabisakot Municipality",
                        "name_nepali": "आठबिसकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sanibheri Rural Municipality",
                        "name_nepali": "सानीभेरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Banphikot Rural Municipality",
                        "name_nepali": "बाँफिकोट गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Musikot Municipality",
                        "name_nepali": "मुसिकोट नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tribeni Rural Municipality",
                        "name_nepali": "त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chaurjahari Municipality",
                        "name_nepali": "चौरजहारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
        ],
    },
    {
        "name": "Province 1",
        "name_nepali": "प्रदेश नं. १",
        "districts": [
            {
                "name": "Taplejung",
                "name_nepali": "ताप्लेजुङ",
                "municipalities": [
                    {
                        "name": "Mikwakhola Rural Municipality",
                        "name_nepali": "मिक्वाखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Maiwakhola Rural Municipality",
                        "name_nepali": "मैवाखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aatharai Tribeni Rural Municipality",
                        "name_nepali": "आठराई त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Phungling Municipality",
                        "name_nepali": "फुङ्लिङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Pathivara Yangwarak Rural Municipality",
                        "name_nepali": "पाथीभरा याङवरक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sirijanga Rural Municipality",
                        "name_nepali": "सिरीजङ्घा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Phaktanlung Rural Municipality",
                        "name_nepali": "फक्ताङलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Meringden Rural Municipality",
                        "name_nepali": "मेरीङदेन गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sidingba Rural Municipality",
                        "name_nepali": "सिदिङ्वा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Sankhuwasabha",
                "name_nepali": "सङ्खुवासभा",
                "municipalities": [
                    {
                        "name": "Bhotkhola Rural Municipality",
                        "name_nepali": "भोटखोला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Makalu Rural Municipality",
                        "name_nepali": "मकालु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Silichong Rural Municipality",
                        "name_nepali": "सिलिचोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chichila Rural Municipality",
                        "name_nepali": "चिचिला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sabhapokhari Rural Municipality",
                        "name_nepali": "सभापोखरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Panchakhapan Municipality",
                        "name_nepali": "पाँचखपन नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chainapur Municipality",
                        "name_nepali": "चैनपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Madi Municipality",
                        "name_nepali": "मादी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Dharmadevi Municipality",
                        "name_nepali": "धर्मदेवी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Khandabari Municipality",
                        "name_nepali": "खाँदवारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Solukhumbu",
                "name_nepali": "सोलुखुम्बु",
                "municipalities": [
                    {
                        "name": "Mahakulung Rural Municipality",
                        "name_nepali": "महाकुलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sotang Rural Municipality",
                        "name_nepali": "सोताङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhudhakoshi Rural Municipality",
                        "name_nepali": "थुलुङ दुधकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhudha Koushika Rural Municipality",
                        "name_nepali": "दुधकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Necha Salyan Rural Municipality",
                        "name_nepali": "नेचासल्यान गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Solu Dhudhakunda Municipality",
                        "name_nepali": "सोलुदुधकुण्ड नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Likhu Pike Rural Municipality",
                        "name_nepali": "लिखु पिके गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khumbu Pasanglhamu Rural Municipality",
                        "name_nepali": "खुम्बु पासाङल्हामु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Okhaldhunga",
                "name_nepali": "ओखलढुङ्गा",
                "municipalities": [
                    {
                        "name": "Siddhicharan Municipality",
                        "name_nepali": "सिद्धिचरण नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Molung Rural Municipality",
                        "name_nepali": "मोलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khiji Demba Rural Municipality",
                        "name_nepali": "खिजीदेम्वा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Likhu Rural Municipality",
                        "name_nepali": "लिखु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Champadevi Rural Municipality",
                        "name_nepali": "चम्पादेवी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunkoshi Rural Municipality",
                        "name_nepali": "सुनकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chishankhu Gadhi Rural Municipality",
                        "name_nepali": "चिशंखुगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Manebhanjyang Rural Municipality",
                        "name_nepali": "मानेभञ्ज्याङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Khotang",
                "name_nepali": "खोटाङ",
                "municipalities": [
                    {
                        "name": "Kepilasgadhi Rural Municipality",
                        "name_nepali": "केपिलासगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aiselukharka Rural Municipality",
                        "name_nepali": "ऐसेलुखर्क गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Lamidanda Rural Municipality",
                        "name_nepali": "लामिडाँडा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Halesi Tuwachung Municipality",
                        "name_nepali": "हलेसी तुवाचुङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sakela Rural Municipality",
                        "name_nepali": "साकेला गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Diprung Rural Municipality",
                        "name_nepali": "दिप्रुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Khotehang Rural Municipality",
                        "name_nepali": "खोटेहाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jante Dhunga Rural Municipality",
                        "name_nepali": "जन्तेढुङ्गा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Barahapokhari Rural Municipality",
                        "name_nepali": "बराहपोखरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Diktel Rupakot Majhuwagadhi Municipality",
                        "name_nepali": "दिक्तेल रुपाकोट मझुवागढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Bhojpur",
                "name_nepali": "भोजपुर",
                "municipalities": [
                    {
                        "name": "Shadananda Municipality",
                        "name_nepali": "षडानन्द नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Tyamke Maiyum Rural Municipality",
                        "name_nepali": "टेम्केमैयुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhojpur Municipality",
                        "name_nepali": "भोजपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Pauwa Dunma Rural Municipality",
                        "name_nepali": "पौवादुङमा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ramprasad Rai Rural Municipality",
                        "name_nepali": "रामप्रसादराई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Hatuwagadhi Rural Municipality",
                        "name_nepali": "हतुवागढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Aamchowk Rural Municipality",
                        "name_nepali": "आमचोक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Salpa Silichho Rural Municipality",
                        "name_nepali": "साल्पासिलिछो गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Arun Rural Municipality",
                        "name_nepali": "अरुण गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Dhankuta",
                "name_nepali": "धनकुटा",
                "municipalities": [
                    {
                        "name": "Pakhribas Municipality",
                        "name_nepali": "पाख्रिबास नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhathar Jorpati Rural Municipality",
                        "name_nepali": "छथर जोरपाटी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dhankuta Municipality",
                        "name_nepali": "धनकुटा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sangurigadhi Rural Municipality",
                        "name_nepali": "साँगुरीगढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chaubise Rural Municipality",
                        "name_nepali": "चौबिसे गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mahalaxmi Municipality",
                        "name_nepali": "महालक्ष्मी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Khalsa Chhintang Sahidbhumi Rural Municipality",
                        "name_nepali": "सहिदभूमि गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Tehrathum",
                "name_nepali": "तेह्रथुम",
                "municipalities": [
                    {
                        "name": "Aatharai Rural Municipality",
                        "name_nepali": "आठराई त्रिवेणी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Phedap Rural Municipality",
                        "name_nepali": "फेदाप गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Menchhayayem Rural Municipality",
                        "name_nepali": "मेन्छयायेम गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Myanglung Municipality",
                        "name_nepali": "म्याङलुङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Laligurans Municipality",
                        "name_nepali": "लालीगुराँस नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chhathar Rural Municipality",
                        "name_nepali": "छथर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Panchthar",
                "name_nepali": "पाँचथर",
                "municipalities": [
                    {
                        "name": "Hilihan Rural Municipality",
                        "name_nepali": "हिलिहाङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Falelung Rural Municipality",
                        "name_nepali": "फालेलुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Phidim Municipality",
                        "name_nepali": "फिदिम नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Falgunanda Rural Municipality",
                        "name_nepali": "फाल्गुनन्द गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kummayak Rural Municipality",
                        "name_nepali": "कुम्मायक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Miklajung Rural Municipality",
                        "name_nepali": "मिक्लाजुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Yangbarak Rural Municipality",
                        "name_nepali": "याङवरक गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tumbewa Rural Municipality",
                        "name_nepali": "तुम्वेवा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Ilam",
                "name_nepali": "इलाम",
                "municipalities": [
                    {
                        "name": "Mai Jogmai Rural Municipality",
                        "name_nepali": "माईजोगमाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sandakpur Rural Municipality",
                        "name_nepali": "सन्दकपुर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ilam Municipality",
                        "name_nepali": "इलाम नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Deumai Municipality",
                        "name_nepali": "देउमाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Mangsebung Rural Municipality",
                        "name_nepali": "माङसेबुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Chulachuli Rural Municipality",
                        "name_nepali": "चुलाचुली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Mai Municipality",
                        "name_nepali": "माई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Suryodaya Municipality",
                        "name_nepali": "सूर्योदय नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rong Rural Municipality",
                        "name_nepali": "रोङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Fakfokathum Rural Municipality",
                        "name_nepali": "फाकफोकथुम गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Jhapa",
                "name_nepali": "झापा",
                "municipalities": [
                    {
                        "name": "Mechinagar Municipality",
                        "name_nepali": "मेचीनगर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Arjundhara Municipality",
                        "name_nepali": "अर्जुनधारा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kankai Municipality",
                        "name_nepali": "कनकाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Shivasatakshi Municipality",
                        "name_nepali": "शिवसताक्षी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kamal Rural Municipality",
                        "name_nepali": "कमल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Damak Municipality",
                        "name_nepali": "दमक नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gauradaha Municipality",
                        "name_nepali": "गौरादह नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Barhadashi Rural Municipality",
                        "name_nepali": "बाह्रदशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Haldibari Rural Municipality",
                        "name_nepali": "हल्दीबारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhadrapur Municipality",
                        "name_nepali": "भद्रपुर नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kachanakawal Rural Municipality",
                        "name_nepali": "कचनकवल गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Buddhashanti Rural Municipality",
                        "name_nepali": "बुद्धशान्ति गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Gauriganj Rural Municipality",
                        "name_nepali": "गौरीगञ्ज गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jhapa Rural Municipality",
                        "name_nepali": "झापा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Birtamod Municipality",
                        "name_nepali": "बिर्तामोड नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                ],
            },
            {
                "name": "Morang",
                "name_nepali": "मोरङ",
                "municipalities": [
                    {
                        "name": "Miklajung Rural Municipality",
                        "name_nepali": "मिक्लाजुङ गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Letang Municipality",
                        "name_nepali": "लेटाङ नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Sundarharaicha Municipality",
                        "name_nepali": "सुन्दरहरैँचा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Belbari Municipality",
                        "name_nepali": "बेलबारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Kanepokhari Rural Municipality",
                        "name_nepali": "कानेपोखरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Pathari Shanishchare Municipality",
                        "name_nepali": "पथरी शनिश्चरे नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Urlabari Municipality",
                        "name_nepali": "उर्लाबारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Ratuwamai Municipality",
                        "name_nepali": "रतुवामाई नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rangeli Municipality",
                        "name_nepali": "रंगेली नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gramthan Rural Municipality",
                        "name_nepali": "ग्रामथान गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Budhiganga Rural Municipality",
                        "name_nepali": "बुढीगंगा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Biratnagar Metropolitan City",
                        "name_nepali": "विराटनगर महानगरपालिका",
                        "municipality_type": "Metropolitan City",
                    },
                    {
                        "name": "Dhanapalthan Rural Municipality",
                        "name_nepali": "धनपालथान गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Jahada Rural Municipality",
                        "name_nepali": "जहदा गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Kerabari Rural Municipality",
                        "name_nepali": "केराबारी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunwarshi Municipality",
                        "name_nepali": "सुनवर्षी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Katahari Rural Municipality",
                        "name_nepali": "कटहरी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Sunsari",
                "name_nepali": "सुनसरी",
                "municipalities": [
                    {
                        "name": "Dharan Sub-Metropolitan City",
                        "name_nepali": "धरान उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Baraha Municipality",
                        "name_nepali": "बराहक्षेत्र नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Koshi Rural Municipality",
                        "name_nepali": "कोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Ramdhuni Municipality",
                        "name_nepali": "रामधुनी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Itahari Sub-Metropolitan City",
                        "name_nepali": "इटहरी उप-महानगरपालिका",
                        "municipality_type": "Sub-Metropolitan City",
                    },
                    {
                        "name": "Duhabi Municipality",
                        "name_nepali": "दुहवी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Gadhi Rural Municipality",
                        "name_nepali": "गढी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Inaruwa Municipality",
                        "name_nepali": "इनरुवा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Harinagara Rural Municipality",
                        "name_nepali": "हरिनगर गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Barju Rural Municipality",
                        "name_nepali": "बर्जु गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Bhokraha Rural Municipality",
                        "name_nepali": "भोक्राहा नरसिंह गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Dewangunj Rural Municipality",
                        "name_nepali": "देवानगञ्ज गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
            {
                "name": "Udayapur",
                "name_nepali": "उदयपुर",
                "municipalities": [
                    {
                        "name": "Belaka Municipality",
                        "name_nepali": "वेलका नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Chaudandigadhi Municipality",
                        "name_nepali": "चौदण्डीगढी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Triyuga Municipality",
                        "name_nepali": "त्रियुगा नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Rautamai Rural Municipality",
                        "name_nepali": "रौतामाई गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Sunkoshi Rural Municipality",
                        "name_nepali": "सुनकोशी गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Katari Municipality",
                        "name_nepali": "कटारी नगरपालिका",
                        "municipality_type": "Municipality",
                    },
                    {
                        "name": "Udayapurgadhi Rural Municipality",
                        "name_nepali": "उदयपुरग गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                    {
                        "name": "Tapli Rural Municipality",
                        "name_nepali": "ताप्ली गाउँपालिका",
                        "municipality_type": "Rural Municipality",
                    },
                ],
            },
        ],
    },
]



from ._datetime import nepalidate, nepalidatetime, nepalitime
from ._formatter import NepaliDateTimeFormatter
from ._humanize import HumanizeDateTime, nepalihumanize
from ._nepalimonth import nepalimonth
from ._nepaliweek import nepaliweek

__all__ = [
    "nepalidate",
    "nepalitime",
    "nepalidatetime",
    "nepalihumanize",
    "nepalimonth",
    "nepaliweek",
    "NepaliDateTimeFormatter",
    "HumanizeDateTime",
]
